@@ -2,7 +2,7 @@ from matplotlib import pyplot
 from shapely.geometry import Point
 from descartes import PolygonPatch
 
-from figures import SIZE, BLUE, GRAY
+from figures import SIZE, BLUE, GRAY, set_limits
 
 fig = pyplot.figure(1, figsize=SIZE, dpi=90)
 
@@ -22,13 +22,7 @@ ax.add_patch(patchc)
 
 ax.set_title('a.difference(b)')
 
-xrange = [-1, 4]
-yrange = [-1, 3]
-ax.set_xlim(*xrange)
-ax.set_xticks(range(*xrange) + [xrange[-1]])
-ax.set_ylim(*yrange)
-ax.set_yticks(range(*yrange) + [yrange[-1]])
-ax.set_aspect(1)
+set_limits(ax, -1, 4, -1, 3)
 
 #2
 ax = fig.add_subplot(122)
@@ -43,13 +37,7 @@ ax.add_patch(patchc)
 
 ax.set_title('b.difference(a)')
 
-xrange = [-1, 4]
-yrange = [-1, 3]
-ax.set_xlim(*xrange)
-ax.set_xticks(range(*xrange) + [xrange[-1]])
-ax.set_ylim(*yrange)
-ax.set_yticks(range(*yrange) + [yrange[-1]])
-ax.set_aspect(1)
+set_limits(ax, -1, 4, -1, 3)
 
 pyplot.show()
 
