@@ -3,22 +3,12 @@ from shapely.geometry import Polygon
 from shapely import affinity
 from descartes.patch import PolygonPatch
 
-from figures import SIZE, BLUE, GRAY
-
-
-def add_origin(ax, geom, origin):
-    x, y = xy = affinity.interpret_origin(geom, origin, 2)
-    ax.plot(x, y, 'o', color=GRAY, zorder=1)
-    ax.annotate(str(xy), xy=xy, ha='center',
-                textcoords='offset points', xytext=(0, 8))
+from figures import SIZE, BLUE, GRAY, set_limits, add_origin
 
 fig = pyplot.figure(1, figsize=SIZE, dpi=90)
 
 triangle = Polygon([(1, 1), (2, 3), (3, 1)])
 
-xrange = [0, 5]
-yrange = [0, 4]
-
 # 1
 ax = fig.add_subplot(121)
 
@@ -34,11 +24,7 @@ add_origin(ax, triangle, 'center')
 
 ax.set_title("a) xfact=1.5, yfact=-1")
 
-ax.set_xlim(*xrange)
-ax.set_xticks(range(*xrange) + [xrange[-1]])
-ax.set_ylim(*yrange)
-ax.set_yticks(range(*yrange) + [yrange[-1]])
-ax.set_aspect(1)
+set_limits(ax, 0, 5, 0, 4)
 
 # 2
 ax = fig.add_subplot(122)
@@ -55,10 +41,6 @@ add_origin(ax, triangle, (1, 1))
 
 ax.set_title("b) xfact=2, origin=(1, 1)")
 
-ax.set_xlim(*xrange)
-ax.set_xticks(range(*xrange) + [xrange[-1]])
-ax.set_ylim(*yrange)
-ax.set_yticks(range(*yrange) + [yrange[-1]])
-ax.set_aspect(1)
+set_limits(ax, 0, 5, 0, 4)
 
 pyplot.show()
