@@ -9,6 +9,7 @@ different z values may intersect or be equal.
 from binascii import a2b_hex
 from ctypes import pointer, c_size_t, c_char_p, c_void_p
 from itertools import islice
+import logging
 import math
 import sys
 from warnings import warn
@@ -21,6 +22,7 @@ from shapely.geos import WKBWriter, WKTWriter
 from shapely.geos import lgeos
 from shapely.impl import DefaultImplementation, delegated
 
+log = logging.getLogger(__name__)
 
 if sys.version_info[0] < 3:
     range = xrange
@@ -220,13 +222,13 @@ class BaseGeometry(object):
     _lgeos = lgeos
 
     def empty(self, val=EMPTY):
-        # TODO: defer cleanup to the implementation. We shouldn't be
-        # explicitly calling a lgeos method here.
-        if not self._is_empty and not self._other_owned and self.__geom__:
+        if not self._other_owned and self.__geom__ and self.__geom__ != EMPTY:
             try:
                 self._lgeos.GEOSGeom_destroy(self.__geom__)
             except (AttributeError, TypeError):
-                pass  # _lgeos might be empty on shutdown
+                # _lgeos might be empty on shutdown
+                log.exception("Failed to delete GEOS geom")
+
         self._is_empty = True
         self.__geom__ = val
 
@@ -450,6 +452,11 @@ class BaseGeometry(object):
         """Unitless length of the geometry (float)"""
         return self.impl['length'](self)
 
+    @property
+    def minimum_clearance(self):
+        """Unitless distance by which a node could be moved to produce an invalid geometry (float)"""
+        return self.impl['minimum_clearance'](self)
+
     # Topological properties
     # ----------------------
 
@@ -538,56 +545,75 @@ class BaseGeometry(object):
     def buffer(self, distance, resolution=16, quadsegs=None,
                cap_style=CAP_STYLE.round, join_style=JOIN_STYLE.round,
                mitre_limit=5.0, single_sided=False):
-        """Returns a geometry with an envelope at a distance from the object's
-        envelope
+        """Get a geometry that represents all points within a distance
+        of this geometry.
+
+        A positive distance produces a dilation, a negative distance an
+        erosion. A very small or zero distance may sometimes be used to
+        "tidy" a polygon.
 
         Parameters
-        ==========
-        distance: float
-            The distance to buffer around the object. A negative distance has a "shrink" effect.
-            A zero distance may be used to "tidy" a polygon.
-        resolution: int, optional
-            The resolution of the buffer around each vertex of the object.
-        quadsegs: int, optional
-            Sets the number of line segments used to approximate an angle fillet.
-            Note: the use of a `quadsegs` parameter is deprecated and will be gone from
-            the next major release.
-        cap_style: int, optional
-            The styles of caps are: CAP_STYLE.round (1), CAP_STYLE.flat (2), and
-            CAP_STYLE.square (3).
-        join_style: int, optional
-            The styles of joins between offset segments are: JOIN_STYLE.round (1),
-            JOIN_STYLE.mitre (2), and JOIN_STYLE.bevel (3).
-        mitre_limit: float, optional
-            The mitre limit ratio is used for very sharp corners. The mitre ratio
-            is the ratio of the distance from the corner to the end of the mitred
-            offset corner. When two line segments meet at a sharp angle, a miter
-            join will extend the original geometry. To prevent unreasonable
-            geometry, the mitre limit allows controlling the maximum length of the
-            join corner. Corners with a ratio which exceed the limit will be
-            beveled.
-        single_side: bool, optional
-            The side used is determined by the sign of the buffer distance:
+        ----------
+        distance : float
+            The distance to buffer around the object.
+        resolution : int, optional
+            The resolution of the buffer around each vertex of the
+            object.
+        quadsegs : int, optional
+            Sets the number of line segments used to approximate an
+            angle fillet.  Note: the use of a `quadsegs` parameter is
+            deprecated and will be gone from the next major release.
+        cap_style : int, optional
+            The styles of caps are: CAP_STYLE.round (1), CAP_STYLE.flat
+            (2), and CAP_STYLE.square (3).
+        join_style : int, optional
+            The styles of joins between offset segments are:
+            JOIN_STYLE.round (1), JOIN_STYLE.mitre (2), and
+            JOIN_STYLE.bevel (3).
+        mitre_limit : float, optional
+            The mitre limit ratio is used for very sharp corners. The
+            mitre ratio is the ratio of the distance from the corner to
+            the end of the mitred offset corner. When two line segments
+            meet at a sharp angle, a miter join will extend the original
+            geometry. To prevent unreasonable geometry, the mitre limit
+            allows controlling the maximum length of the join corner.
+            Corners with a ratio which exceed the limit will be beveled.
+        single_side : bool, optional
+            The side used is determined by the sign of the buffer
+            distance:
+
                 a positive distance indicates the left-hand side
                 a negative distance indicates the right-hand side
-            The single-sided buffer of point geometries is the same as the regular buffer.
-            The End Cap Style for single-sided buffers is always ignored, and forced to the
-            equivalent of CAP_FLAT.
 
-        Example:
+            The single-sided buffer of point geometries is the same as
+            the regular buffer.  The End Cap Style for single-sided
+            buffers is always ignored, and forced to the equivalent of
+            CAP_FLAT.
+
+        Returns
+        -------
+        Geometry
+
+        Notes
+        -----
+        The return value is a strictly two-dimensional geometry. All
+        Z coordinates of the original geometry will be ignored.
+
+        Examples
+        --------
+        >>> from shapely.wkt import loads
+        >>> g = loads('POINT (0.0 0.0)')
+        >>> g.buffer(1.0).area        # 16-gon approx of a unit radius circle
+        3.1365484905459389
+        >>> g.buffer(1.0, 128).area   # 128-gon approximation
+        3.1415138011443009
+        >>> g.buffer(1.0, 3).area     # triangle approximation
+        3.0
+        >>> list(g.buffer(1.0, cap_style=CAP_STYLE.square).exterior.coords)
+        [(1.0, 1.0), (1.0, -1.0), (-1.0, -1.0), (-1.0, 1.0), (1.0, 1.0)]
+        >>> g.buffer(1.0, cap_style=CAP_STYLE.square).area
+        4.0
 
-          >>> from shapely.wkt import loads
-          >>> g = loads('POINT (0.0 0.0)')
-          >>> g.buffer(1.0).area        # 16-gon approx of a unit radius circle
-          3.1365484905459389
-          >>> g.buffer(1.0, 128).area   # 128-gon approximation
-          3.1415138011443009
-          >>> g.buffer(1.0, 3).area     # triangle approximation
-          3.0
-          >>> list(g.buffer(1.0, cap_style=CAP_STYLE.square).exterior.coords)
-          [(1.0, 1.0), (1.0, -1.0), (-1.0, -1.0), (-1.0, 1.0), (1.0, 1.0)]
-          >>> g.buffer(1.0, cap_style=CAP_STYLE.square).area
-          4.0
         """
         if quadsegs is not None:
             warn(
@@ -596,6 +622,7 @@ class BaseGeometry(object):
             res = quadsegs
         else:
             res = resolution
+
         if mitre_limit == 0.0:
             raise ValueError(
                 'Cannot compute offset from zero-length line segment')
