@@ -11,7 +11,7 @@ This is layer number 2 from the list below.
 Shapely 1.2 includes a GEOS backend and it is the default.
 """
 
-from .ftools import wraps
+from functools import wraps
 
 from shapely.algorithms import cga
 from shapely.coords import BoundsOp
@@ -21,6 +21,13 @@ from shapely.predicates import BinaryPredicate, UnaryPredicate
 from shapely.topology import BinaryRealProperty, BinaryTopologicalOp
 from shapely.topology import UnaryRealProperty, UnaryTopologicalOp
 
+
+class ImplementationError(
+        AttributeError, KeyError, NotImplementedError):
+    """To be raised when the registered implementation does not
+    support the requested method."""
+
+
 def delegated(func):
     """A delegated method raises AttributeError in the absence of backend
     support."""
@@ -29,27 +36,43 @@ def delegated(func):
         try:
             return func(*args, **kwargs)
         except KeyError:
-            raise AttributeError("Method %r is not supported by %r" %
-                                 (func.__name__, args[0].impl))
+            raise ImplementationError(
+                "Method '%s' not provided by registered "
+                "implementation '%s'" % (func.__name__, args[0].impl))
     return wrapper
 
 # Map geometry methods to their GEOS delegates
 
+
 class BaseImpl(object):
+    """Base class for registrable implementations."""
+
     def __init__(self, values):
         self.map = dict(values)
+
     def update(self, values):
         self.map.update(values)
+
     def __getitem__(self, key):
-        return self.map[key]
+        try:
+            return self.map[key]
+        except KeyError:
+            raise ImplementationError(
+                "Method '%s' not provided by registered "
+                "implementation '%s'" % (key, self.map))
+
     def __contains__(self, key):
         return key in self.map
 
+
 class GEOSImpl(BaseImpl):
+    """GEOS implementation"""
+
     def __repr__(self):
         return '<GEOSImpl object: GEOS C API version %s>' % (
             lgeos.geos_capi_version,)
 
+
 IMPL300 = {
     'area': (UnaryRealProperty, 'area'),
     'distance': (BinaryRealProperty, 'distance'),
@@ -85,6 +108,7 @@ IMPL300 = {
     'within': (BinaryPredicate, 'within'),
     'covers': (BinaryPredicate, 'covers'),
     'equals_exact': (BinaryPredicate, 'equals_exact'),
+    'relate_pattern': (BinaryPredicate, 'relate_pattern'),
 
     # First pure Python implementation
     'is_ccw': (cga.is_ccw_impl, 'is_ccw'),
@@ -116,10 +140,17 @@ IMPL320 = {
     'interpolate_normalized': (InterpolateOp, 'interpolate_normalized'),
     'interpolate': (InterpolateOp, 'interpolate'),
     'buffer_with_style': (UnaryTopologicalOp, 'buffer_with_style'),
+    'hausdorff_distance': (BinaryRealProperty, 'hausdorff_distance'),
     }
 
 IMPL330 = {
-    'is_closed': (UnaryPredicate, 'is_closed')}
+    'is_closed': (UnaryPredicate, 'is_closed'),
+    'buffer_with_params': (UnaryTopologicalOp, 'buffer_with_params'),
+}
+
+IMPL360 = {
+    'minimum_clearance': (UnaryRealProperty, 'minimum_clearance')
+}
 
 def impl_items(defs):
     return [(k, v[0](v[1])) for k, v in list(defs.items())]
@@ -133,5 +164,7 @@ if lgeos.geos_version >= (3, 2, 0):
     imp.update(impl_items(IMPL320))
 if lgeos.geos_version >= (3, 3, 0):
     imp.update(impl_items(IMPL330))
+if lgeos.geos_version >= (3, 6, 0):
+    imp.update(impl_items(IMPL360))
 
 DefaultImplementation = imp
